@@ -33,7 +33,7 @@
 #include <libsoup/soup.h>
 #include <string.h>
 
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
 #include <libsoup/soup-address.h>
 #include <libsoup/soup-server.h>
 #include <libsoup/soup-server-auth.h>
@@ -177,7 +177,7 @@ struct _EpcAuthContext
   EpcPublisher   *publisher;
   const gchar    *key;
 
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
   SoupServerAuth *auth;
 #else
   SoupMessage    *message;
@@ -224,7 +224,7 @@ struct _EpcPublisherPrivate
   GMainLoop             *server_loop;
   SoupServer            *server;
 
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
   SoupServerAuthContext  server_auth;
 #else
   SoupAuthDomain        *server_auth;
@@ -245,7 +245,7 @@ struct _EpcPublisherPrivate
   gchar                 *private_key_file;
 };
 
-static GStaticRecMutex epc_publisher_lock;
+static GRecMutex epc_publisher_lock;
 
 G_DEFINE_TYPE (EpcPublisher, epc_publisher, G_TYPE_OBJECT);
 
@@ -431,7 +431,7 @@ epc_publisher_track_client (EpcPublisher *self,
                             SoupServer   *server,
                             SoupSocket   *socket)
 {
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
 
   if (epc_publisher_check_client (self, server, socket))
     {
@@ -446,7 +446,7 @@ epc_publisher_track_client (EpcPublisher *self,
       return TRUE;
     }
   else
-    g_static_rec_mutex_unlock (&epc_publisher_lock);
+    g_rec_mutex_unlock (&epc_publisher_lock);
 
   return FALSE;
 }
@@ -467,7 +467,7 @@ epc_publisher_untrack_client (EpcPublisher *self,
       g_hash_table_replace (self->priv->clients, socket, tag);
     }
 
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 }
 
 static void
@@ -524,16 +524,16 @@ epc_publisher_handle_contents (SoupServer        *server,
 
   if (contents)
     {
-      gconstpointer data;
+      gconstpointer contents_data;
       const gchar *type;
       gsize length = 0;
 
-      data = epc_contents_get_data (contents, &length);
+      contents_data = epc_contents_get_data (contents, &length);
       type = epc_contents_get_mime_type (contents);
 
-      if (data)
+      if (contents_data)
         {
-          soup_message_set_response (message, type, SOUP_MEMORY_COPY, (gpointer) data, length);
+          soup_message_set_response (message, type, SOUP_MEMORY_COPY, (gpointer) contents_data, length);
           soup_message_set_status (message, SOUP_STATUS_OK);
         }
       else if (epc_contents_is_stream (contents))
@@ -718,7 +718,7 @@ epc_publisher_handle_root (SoupServer        *server,
 }
 
 static void
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
 epc_auth_context_init (EpcAuthContext *context,
                        EpcPublisher   *publisher,
                        SoupMessage    *message,
@@ -737,7 +737,7 @@ epc_auth_context_init (EpcAuthContext *context,
   context->key = epc_publisher_get_key (uri->path);
   context->resource = NULL;
 
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
   context->auth = auth;
 #else
   context->message  = message;
@@ -751,7 +751,7 @@ epc_auth_context_init (EpcAuthContext *context,
     context->resource = publisher->priv->default_resource;
 }
 
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
 
 static gboolean
 epc_publisher_server_auth_cb (SoupServerAuthContext *auth_ctx G_GNUC_UNUSED,
@@ -763,7 +763,7 @@ epc_publisher_server_auth_cb (SoupServerAuthContext *auth_ctx G_GNUC_UNUSED,
   const char *user = NULL;
   EpcAuthContext context;
 
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
   epc_auth_context_init (&context, EPC_PUBLISHER (data), message, auth);
 
   if (NULL != auth)
@@ -778,7 +778,7 @@ epc_publisher_server_auth_cb (SoupServerAuthContext *auth_ctx G_GNUC_UNUSED,
              context.key, context.resource, context.resource ? context.resource->auth_handler : NULL,
              authorized);
 
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 
   return authorized;
 }
@@ -793,7 +793,7 @@ epc_publisher_auth_filter (SoupAuthDomain *domain G_GNUC_UNUSED,
   gboolean authorized = TRUE;
   EpcAuthContext context;
 
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
   epc_auth_context_init (&context, EPC_PUBLISHER (data), message, NULL, NULL);
   authorized = (!context.resource || !context.resource->auth_handler);
 
@@ -802,7 +802,7 @@ epc_publisher_auth_filter (SoupAuthDomain *domain G_GNUC_UNUSED,
              context.key, context.resource, context.resource ? context.resource->auth_handler : NULL,
              authorized);
 
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 
   return !authorized;
 }
@@ -817,7 +817,7 @@ epc_publisher_basic_auth_cb (SoupAuthDomain *domain G_GNUC_UNUSED,
   gboolean authorized = TRUE;
   EpcAuthContext context;
 
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
   epc_auth_context_init (&context, EPC_PUBLISHER (data), message, username, password);
 
   if (context.resource && context.resource->auth_handler)
@@ -828,7 +828,7 @@ epc_publisher_basic_auth_cb (SoupAuthDomain *domain G_GNUC_UNUSED,
              context.key, context.resource, context.resource ? context.resource->auth_handler : NULL,
              authorized);
 
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 
   return authorized;
 }
@@ -842,7 +842,7 @@ epc_publisher_generic_auth_cb (SoupAuthDomain *domain G_GNUC_UNUSED,
   gboolean authorized = TRUE;
   EpcAuthContext context;
 
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
   epc_auth_context_init (&context, EPC_PUBLISHER (data), message, username, NULL);
 
   if (context.resource && context.resource->auth_handler)
@@ -853,7 +853,7 @@ epc_publisher_generic_auth_cb (SoupAuthDomain *domain G_GNUC_UNUSED,
              context.key, context.resource, context.resource ? context.resource->auth_handler : NULL,
              authorized);
 
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 
   return authorized;
 }
@@ -866,7 +866,7 @@ epc_publisher_init (EpcPublisher *self)
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, EPC_TYPE_PUBLISHER, EpcPublisherPrivate);
   self->priv->protocol = EPC_PROTOCOL_HTTPS;
 
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
   self->priv->server_auth.types = SOUP_AUTH_TYPE_DIGEST;
   self->priv->server_auth.callback = epc_publisher_server_auth_cb;
   self->priv->server_auth.user_data = self;
@@ -911,6 +911,10 @@ epc_publisher_get_bookmark_type (EpcPublisher *self)
 
       case EPC_PROTOCOL_UNKNOWN:
         break;
+
+      default:
+        g_warning ("%s: Unexpected protocol.", G_STRFUNC);
+        break;
     }
 
   return NULL;
@@ -1079,7 +1083,7 @@ epc_publisher_compute_name (EpcPublisher *self)
 static void
 epc_publisher_remove_handlers (EpcPublisher *self)
 {
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
   memset (&self->priv->server_auth.digest_info, 0,
           sizeof self->priv->server_auth.digest_info);
 #else
@@ -1103,7 +1107,7 @@ epc_publisher_add_server_callback (EpcPublisher       *self,
                                    const gchar        *path,
                                    SoupServerCallback  callback)
 {
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
   soup_server_add_handler (self->priv->server, path,
                            &self->priv->server_auth,
                            callback, NULL, self);
@@ -1116,7 +1120,7 @@ epc_publisher_add_server_callback (EpcPublisher       *self,
 static void
 epc_publisher_install_handlers (EpcPublisher *self)
 {
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
 
   memset (&self->priv->server_auth.digest_info, 0,
           sizeof self->priv->server_auth.digest_info);
@@ -1307,7 +1311,7 @@ epc_publisher_real_set_auth_flags (EpcPublisher *self,
   if (self->priv->server)
     epc_publisher_remove_handlers (self);
 
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
   self->priv->server_auth.types =
     flags & EPC_AUTH_PASSWORD_TEXT_NEEDED ?
     SOUP_AUTH_TYPE_BASIC : SOUP_AUTH_TYPE_DIGEST;
@@ -1676,7 +1680,7 @@ epc_publisher_class_init (EpcPublisherClass *cls)
                                                         G_PARAM_STATIC_BLURB));
 
   g_type_class_add_private (cls, sizeof (EpcPublisherPrivate));
-  g_static_rec_mutex_init (&epc_publisher_lock);
+  g_rec_mutex_init (&epc_publisher_lock);
 }
 
 /**
@@ -1806,12 +1810,12 @@ epc_publisher_add_handler (EpcPublisher      *self,
   g_return_if_fail (NULL != handler);
   g_return_if_fail (NULL != key);
 
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
 
   resource = epc_resource_new (handler, user_data, destroy_data);
   g_hash_table_insert (self->priv->resources, g_strdup (key), resource);
 
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 }
 
 /**
@@ -1909,7 +1913,7 @@ epc_publisher_remove (EpcPublisher *self,
   g_return_val_if_fail (EPC_IS_PUBLISHER (self), FALSE);
   g_return_val_if_fail (NULL != key, FALSE);
 
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
 
   if (self->priv->default_bookmark &&
       g_str_equal (key, self->priv->default_bookmark))
@@ -1922,7 +1926,7 @@ epc_publisher_remove (EpcPublisher *self,
     }
 
   success = g_hash_table_remove (self->priv->resources, key);
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 
   return success;
 }
@@ -1953,14 +1957,14 @@ epc_publisher_lookup (EpcPublisher *self,
   g_return_val_if_fail (EPC_IS_PUBLISHER (self), NULL);
   g_return_val_if_fail (NULL != key, NULL);
 
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
 
   resource = g_hash_table_lookup (self->priv->resources, key);
 
   if (resource)
     data = resource->user_data;
 
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 
   return data;
 }
@@ -1989,9 +1993,9 @@ epc_publisher_has_key (EpcPublisher *self,
   g_return_val_if_fail (EPC_IS_PUBLISHER (self), FALSE);
   g_return_val_if_fail (NULL != key, FALSE);
 
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
   resource = g_hash_table_lookup (self->priv->resources, key);
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 
   return (NULL != resource);
 }
@@ -2046,13 +2050,13 @@ epc_publisher_list (EpcPublisher *self,
   if (pattern && *pattern)
     context.pattern = g_pattern_spec_new (pattern);
 
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
 
   g_hash_table_foreach (self->priv->resources,
                         epc_publisher_list_cb,
                         &context);
 
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 
   if (context.pattern)
     g_pattern_spec_free (context.pattern);
@@ -2097,7 +2101,7 @@ epc_publisher_set_auth_handler (EpcPublisher   *self,
   g_return_if_fail (EPC_IS_PUBLISHER (self));
   g_return_if_fail (NULL != handler);
 
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
 
   resource = epc_publisher_find_resource (self, key);
 
@@ -2106,7 +2110,7 @@ epc_publisher_set_auth_handler (EpcPublisher   *self,
   else
     g_warning ("%s: No resource handler found for key `%s'", G_STRFUNC, key);
 
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 }
 
 /**
@@ -2143,7 +2147,7 @@ epc_publisher_add_bookmark (EpcPublisher *self,
 
   g_return_if_fail (EPC_IS_PUBLISHER (self));
 
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
 
   resource = epc_publisher_find_resource (self, key);
 
@@ -2160,7 +2164,7 @@ epc_publisher_add_bookmark (EpcPublisher *self,
   else
     g_warning ("%s: No resource handler found for key `%s'", G_STRFUNC, key);
 
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 }
 
 /**
@@ -2477,7 +2481,7 @@ epc_publisher_run_async (EpcPublisher  *self,
   if (!self->priv->server_started)
     {
       soup_server_run_async (self->priv->server);
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
       g_object_unref (self->priv->server); /* work arround bug #494128 */
 #endif
       self->priv->server_started = TRUE;
@@ -2531,7 +2535,7 @@ epc_publisher_quit (EpcPublisher *self)
   if (self->priv->server_loop)
     g_main_loop_quit (self->priv->server_loop);
 
-  g_static_rec_mutex_lock (&epc_publisher_lock);
+  g_rec_mutex_lock (&epc_publisher_lock);
 
   if (self->priv->clients)
     g_hash_table_foreach (self->priv->clients,
@@ -2541,7 +2545,7 @@ epc_publisher_quit (EpcPublisher *self)
   g_slist_foreach (idle_clients, (GFunc) soup_socket_disconnect, NULL);
   g_slist_free (idle_clients);
 
-  g_static_rec_mutex_unlock (&epc_publisher_lock);
+  g_rec_mutex_unlock (&epc_publisher_lock);
 
   if (self->priv->dispatcher)
     {
@@ -2685,6 +2689,10 @@ epc_publisher_expand_name (const gchar  *name,
           case '%':
             subst = "%";
             break;
+
+          default:
+            g_warning ("%s: Unexpected character.", G_STRFUNC);
+            break;
         }
 
       if (subst)
@@ -2754,7 +2762,7 @@ epc_auth_context_get_password (const EpcAuthContext *context)
 {
   g_return_val_if_fail (NULL != context, NULL);
 
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
 
   if (NULL != context->auth &&
       SOUP_AUTH_TYPE_BASIC == context->auth->type)
@@ -2788,7 +2796,7 @@ epc_auth_context_check_password (const EpcAuthContext *context,
   g_return_val_if_fail (NULL != context, FALSE);
   g_return_val_if_fail (NULL != password, FALSE);
 
-#if HAVE_LIBSOUP22
+#ifdef HAVE_LIBSOUP22
 
   return
     NULL != context->auth &&
