@@ -175,15 +175,10 @@ epc_tls_private_key_new (GError **error)
   context.rc = gnutls_x509_privkey_init (&context.key);
   epc_tls_check (context.rc);
 
-  if (g_thread_supported ())
-    {
-      context.loop = g_main_loop_new (NULL, FALSE);
-      g_thread_create (epc_tls_private_key_thread, &context, FALSE, NULL);
-      g_main_loop_run (context.loop);
-      g_main_loop_unref (context.loop);
-    }
-  else
-    epc_tls_private_key_thread (&context);
+  context.loop = g_main_loop_new (NULL, FALSE);
+  g_thread_new (NULL, epc_tls_private_key_thread, &context);
+  g_main_loop_run (context.loop);
+  g_main_loop_unref (context.loop);
 
   epc_tls_check (context.rc);
 
